@@ -1,5 +1,5 @@
 package App::TeleGramma::BotAction::Listen;
-$App::TeleGramma::BotAction::Listen::VERSION = '0.06';
+$App::TeleGramma::BotAction::Listen::VERSION = '0.07';
 # ABSTRACT: Base class for bot actions that listen
 
 use Mojo::Base 'App::TeleGramma::BotAction';
@@ -16,7 +16,15 @@ sub process_message {
 
   my $cmd = $self->command;
 
-  if ($msg->text && $msg->text =~ /^\Q$cmd\E \b @? /x) {
+  if ($msg->text && ! ref($cmd) && $msg->text =~ /^\Q$cmd\E \b @?/x) {
+    my ($body) = ($msg->text =~ /^ \S+ \s+ (.*)$/x);
+    return $self->response->($msg, $body) if defined $body; # return body of command, if it existed
+    return $self->response->($msg);
+  }
+
+  if ($msg->text && ref($cmd) eq 'Regexp' && $msg->text =~ $cmd) {
+    my $body = ($msg->text);
+    return $self->response->($msg, $body) if defined $body; # return body of command, if it existed
     return $self->response->($msg);
   }
 
@@ -37,7 +45,7 @@ App::TeleGramma::BotAction::Listen - Base class for bot actions that listen
 
 =head1 VERSION
 
-version 0.06
+version 0.07
 
 =head1 AUTHOR
 
